=========
PyAirfoil
=========


.. image:: https://img.shields.io/pypi/v/pyairfoil.svg
        :target: https://pypi.python.org/pypi/pyairfoil

.. image:: https://img.shields.io/travis/rogersjw/pyairfoil.svg
        :target: https://travis-ci.org/rogersjw/pyairfoil

.. image:: https://readthedocs.org/projects/pyairfoil/badge/?version=latest
        :target: https://pyairfoil.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




PyAirfoil contains methods and objects related to generating airfoil geometries


* Free software: MIT license
* Documentation: https://pyairfoil.readthedocs.io.


Features
--------

* None right now... More to come soon.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
